//
//  N5SplitViewController.m
//  N5SplitViewController
//
//  Created by Julien Vignali on 15.12.11.
//  Copyright (c) 2011 __MyCompanyName__. All rights reserved.
//

#import "N5SplitViewController.h"

@interface N5SplitViewController()
-(void)updateTopView;
-(void)updateBottomView;
@end

#pragma mark -

@implementation N5SplitViewController
{
    @private
    CGRect topRect;
    CGRect bottomRect;
}
@synthesize topViewController       = _topViewController;
@synthesize bottomViewController    = _bottomViewController;
@synthesize visibility              = _visibility;

#pragma mark - Initialization

-(id)init
{
    self = [super init];
    if (self) {
        _visibility = N5SplitViewControllerTopVisible;
    }
    return self;
}

-(id)initWithTopViewController:(UIViewController *)topViewController 
          bottomViewController:(UIViewController *)bottomViewController
                    visibility:(N5SplitViewControllerVisibility)visibility
{
    self = [super init];
    if (self) {
        self.topViewController = topViewController;
        self.bottomViewController = bottomViewController;
        _visibility = visibility;
    }
    return self;
}

#pragma mark - Top and bottom view controllers

-(void)updateTopView
{
    self.topViewController.view.frame = topRect;
    NSLog(@"%s", __PRETTY_FUNCTION__);
    [self.view addSubview:self.topViewController.view];
}

-(void)setTopViewController:(UIViewController *)topViewController
{
    if (_topViewController != nil) {
        [_topViewController removeFromParentViewController];
    }
    [_topViewController autorelease];
    _topViewController = [topViewController retain];
    [self addChildViewController:_topViewController];
    [_topViewController didMoveToParentViewController:self];
    if ([self isViewLoaded]) {
        [self updateTopView];
    }
}

-(void)updateBottomView
{
    self.bottomViewController.view.frame = bottomRect;
    NSLog(@"%s", __PRETTY_FUNCTION__);
    [self.view addSubview:self.bottomViewController.view];
}

-(void)setBottomViewController:(UIViewController *)bottomViewController
{
    if (_bottomViewController != nil) {
        [_bottomViewController removeFromParentViewController];
    }
    [_bottomViewController autorelease];
    _bottomViewController = [bottomViewController retain];
    [self addChildViewController:_bottomViewController];
    [_bottomViewController didMoveToParentViewController:self];
    if ([self isViewLoaded]) {
        [self updateBottomView];
    }
}

-(N5SplitViewControllerVisibility)currentVisibility
{
    return _visibility;
}

#pragma mark - View lifecycle

-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    NSLog(@"%s", __PRETTY_FUNCTION__);
}

-(void)viewWillLayoutSubviews
{
    [super viewWillLayoutSubviews];
    CGRect rect = self.view.bounds;
    CGRectDivide(rect, &topRect, &bottomRect, CGRectGetMidY(rect), CGRectMinYEdge);
    _topViewController.view.frame = topRect;
    _bottomViewController.view.frame = bottomRect;
    //NSLog(@"%s %@", __PRETTY_FUNCTION__, NSStringFromCGRect(self.view.bounds));
}

-(void)viewDidLayoutSubviews
{
    [super viewDidLayoutSubviews];
    //NSLog(@"%s %@", __PRETTY_FUNCTION__, NSStringFromCGRect(self.view.bounds));
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    NSLog(@"%s", __PRETTY_FUNCTION__);
    CGRect rect = self.view.bounds;
    CGRectDivide(rect, &topRect, &bottomRect, CGRectGetMidY(rect), CGRectMinYEdge);
    [self updateTopView];
    [self updateBottomView];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    NSLog(@"%s", __PRETTY_FUNCTION__);
    self.topViewController = nil;
    self.bottomViewController = nil;
}

#pragma mark - Interface orientation

-(BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return YES;
}

-(void)willRotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration
{
    NSLog(@"%s", __PRETTY_FUNCTION__);
    /*[UIView animateWithDuration:duration animations:^{
        [self layoutForOrientation:toInterfaceOrientation];
    }];*/
}

#pragma mark - Deallocating 

- (void)dealloc
{
    [_topViewController release];
    [_bottomViewController release];
    [super dealloc];
}

@end
